Matroid Theory
==============

Basics
------

.. toctree::
   :maxdepth: 1

   sage/matroids/constructor
   sage/matroids/matroid

Database of matroids
--------------------

.. toctree::
   :maxdepth: 1

   sage/matroids/matroids_catalog
   sage/matroids/database_collections
   sage/matroids/database_matroids

Concrete implementations
------------------------

.. toctree::
   :maxdepth: 1

   sage/matroids/basis_matroid
   sage/matroids/circuits_matroid
   sage/matroids/circuit_closures_matroid
   sage/matroids/flats_matroid
   sage/matroids/linear_matroid
   sage/matroids/rank_matroid
   sage/matroids/graphic_matroid

Chow rings of matroids
----------------------

.. toctree::
   :maxdepth: 1

   sage/matroids/chow_ring_ideal
   sage/matroids/chow_ring

Abstract matroid classes
------------------------

.. toctree::
   :maxdepth: 1

   sage/matroids/dual_matroid
   sage/matroids/minor_matroid
   sage/matroids/basis_exchange_matroid

Advanced functionality
----------------------

.. toctree::
   :maxdepth: 1

   sage/matroids/advanced
   sage/matroids/utilities
   sage/matroids/extension

Internals
---------

.. toctree::
   :maxdepth: 1

   sage/matroids/lean_matrix
   sage/matroids/matroids_plot_helpers
   sage/matroids/set_system
   sage/matroids/unpickling

.. include:: ../footer.txt
